@@ -1,5 +1,6 @@
 use x_log::*;
 
+#[derive(Debug)]
 struct Position {
     x: f32,
     y: f32
@@ -27,5 +28,7 @@ fn main() {
     info!("x is {} and y is {}",
        if pos.x >= 0.0 { "positive" } else { "negative" },
        if pos.y >= 0.0 { "positive" } else { "negative" });
+
+    valv!(pos);
 }
 
