@@ -12,6 +12,6 @@ fn main() {
     let v1 = "123";
     let v2 = vec![4,5,6];
 
-    info!("print some value below.");
+    info!("print some values below.");
     valn!(v1, v2);
 }
\ No newline at end of file
